[gs-cvs] rev 7141 - trunk/gs/src

lpd at ghostscript.com lpd at ghostscript.com
Tue Oct 31 12:58:38 PST 2006


Author: lpd
Date: 2006-10-31 12:58:38 -0800 (Tue, 31 Oct 2006)
New Revision: 7141

Modified:
   trunk/gs/src/iutil.c
Log:
Fixes a bug that caused certain 1-operand math operators to return typecheck
rather than stackunderflow if the stack was empty.  Fixes a discrepancy in
PS3 CET 25-05-1.


Modified: trunk/gs/src/iutil.c
===================================================================
--- trunk/gs/src/iutil.c	2006-10-31 17:36:29 UTC (rev 7140)
+++ trunk/gs/src/iutil.c	2006-10-31 20:58:38 UTC (rev 7141)
@@ -839,7 +839,7 @@
 }
 
 /* Get a single real parameter. */
 /* The only possible error is e_typecheck. */
 /* If an error is returned, the return value is not updated. */
 int
 real_param(const ref * op, double *pparam)
@@ -851,6 +851,8 @@
 	case t_real:
 	    *pparam = op->value.realval;
 	    break;
+        case t__invalid:
+	    return_error(e_stackunderflow);
 	default:
 	    return_error(e_typecheck);
     }
@@ -839,7 +839,7 @@
 
 /* Get a single real parameter. */
-/* The only possible error is e_typecheck. */
+/* The only possible errors are e_typecheck and e_stackunderflow. */
 /* If an error is returned, the return value is not updated. */
 int



More information about the gs-cvs mailing list